# --8<--8<--8<--8<--
#
# Copyright (C) 2007 Smithsonian Astrophysical Observatory
#
# This file is part of mst-cpan
#
# mst-cpan is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# mst-cpan is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the 
#       Free Software Foundation, Inc. 
#       51 Franklin Street, Fifth Floor
#       Boston, MA  02110-1301, USA
#
# -->8-->8-->8-->8--

package MST::CPAN::Handler::PDL;

use strict;
use warnings;

use Config;
use base 'MST::CPAN::Handler';

sub setvalue
{
    my ( $flag, $value ) = @_;

    return ( qr/^\s*$flag.*/ => "$flag => $value," );
}

sub install
{
    my ( $self ) = @_;

    # standard configuration changes to perldl.conf
    my @perldl_conf = 
      (
       setvalue( WITH_BADVAL => 1 ),
       setvalue( BADVAL_USENAN => 1 ),
       setvalue( WITH_IO_BROWSER => 1 ),
      );

    #-------------------------------------------------
    # put the pdl binary executable in the correct directory
    $self->fix_file ( 'pdl.PL',
		      'gcc -o pdl' => 'mkdir -p blib/bin && ' . $Config{cc} . ' -o blib/bin/pdl',
		    );

    my @makefile_pl = 
      (
       q{unshift @exe_files, 'pdl';} => '',
       q{$cleanup = 'pdl pdl.c ' . $cleanup;} => '',
      );

    #-------------------------------------------------
    # work around braindead local /usr/local 32 bit pollution
    if (    $::opt{SysArch}{os_type} eq 'linux'
         && $::opt{SysArch}{hw_cpu_generic} eq 'x86_64'
	 && -f '/usr/local/karma/bin/tx'
	 && `file /usr/local/karma/bin/tx` =~ /32-bit/
       )
    {
	push @perldl_conf, setvalue( WITH_KARMA => 0 );
    }


    #-------------------------------------------------
    # work around braindead redhat Perl mods
    if ( $::opt{SysArch}{os_vendor} eq 'RHFC' )
    {
	push @makefile_pl, ( 'WriteMakefile(' => 
			     "WriteMakefile(\n\tUSE_MM_LD_RUN_PATH=>1," );
    }

    #-------------------------------------------------
    # work around problems with FC6
    if (    $::opt{SysArch}{os_vendor} eq 'RHFC'
         && $::opt{SysArch}{os_version} == 6 )
    {
	push @perldl_conf, 
          setvalue( WITH_PROJ => 0),
          setvalue( WITH_3D => 0);
    }

    #-------------------------------------------------
    # don't bother with OpenGL on Solaris; no time to figure out
    # why it fails to compile
    if ( $::opt{SysArch}{os_type} eq 'solaris' )
    {
	push @perldl_conf, setvalue( WITH_3D => 0);
    }

    #-------------------------------------------------
    # don't bother with OpenGL anywhere.  too much of a pain
    # to figure out why it fails to compile
    push @perldl_conf, setvalue( WITH_3D => 0 );

    #-------------------------------------------------
    # fix the files.
    $self->fix_file( 'perldl.conf', @perldl_conf );
    $self->fix_MakefilePL( @makefile_pl );


    $self->SUPER::install( );
}


1;
